#pragma rtGlobals=1		// Use modern global access method.

//This program is based on the Algorithm, published by Chan, Pashley and White, and is used to predict the electrostatic
//force between two identically charged solids in water, by numerical solution of the poisson boltzman equation.  I have based this procedure
//on a commonly used Pascal code that runs in the MSDOS prompt.  I do not know who originally wrote the Pascal program,but it was 
//extensively modified by Alexis Grabbe.  
//This Igor procedure was written by Clayton T. McKee 

//IMPORTANT.  For this file to run properly, you must save the DLVO Fitting.IPF file (with that name) in the "UserProcedures" file under the wavemetrics file folder, and 
//make sure the following is written in the main procedure window: #include "DLVO Fitting".  The following global variables must also be present in the root folder:  IonicStrength, 
//SurfacePotential, Hamaker, ChargeDensity, DC, AreaPCharge, vdW, and Temp (they should be there).  If they are not present, first make sure the variables check box is highlighted
// in the data browser, if still not present when checked, simply type Variable/G IonicStrength SurfacePotential  etc. in the command window, when the red arrow in the data browser is pointed to the root folder.


//CONSTANT POTENTIAL
Function RungaKuttaCP()
	Variable Q, Xscal 									// Q = dY/dX, Xscal = scaled distance from midplane.  Both unitless quantities									
	Variable A, B, C, D, step, Ys, ym, p, i, j, n,l, h,pmax, kappa, conv,TwoNkT, Debye
	nVar v1 = root:surfacepotential
	nVar v2 = root:Hamaker
	nVar v3 = root:ionicstrength
	nVar v4 = root:vdW
	nVar v5 = root:Temp
	nVar v6 = root:DC
	nVar v7 = root:SphereRadius
	
	// variable declarations
	Q = 0;Xscal=0										// at midplane both values are zero
	p = 1;i=0;n=0;j=0										// p is the pressure variable and begins at 1 Erg/cm3, i,n, and j are loop variables
	TwoNkt = 2*1.380658e-16*v5*(v3)*6.02213e23/1000		// units of Erg/cm3.  Boltzman constant Erg/K.   Pressure = 2nKT(cosh(Ym) -1)  
	conv = v6*1.380658e-16*v5/(2*PI*(4.803e-10)^2)			// units of Erg/(Statcoulumbs)^2,   electron charge unit StatCoulumbs.  
	kappa = 1e8*sqrt((1000*conv)/(4*6.02213e23))			
	Ys =v1*1.602e-19/(1.380658e-23*v5)					//unitless surface potential at zero distance from wall
	pmax =TwoNkt*(cosh(ys) - 1)							//maximum pressure when the potential at midplane is equal to the surface potential, sets the boundary of constant potential		
	Debye = (kappa/(sqrt(v3)))*1e-8							//debye length in units of cm
//	print debye*1e7
	
	
	//Create some data folders to place the data in
	if(datafolderexists("root:ConstantPotential"))
	setdatafolder root:ConstantPotential
	else
	newdatafolder/s root:ConstantPotential
	setdatafolder root:ConstantPotential
	endif
	
	//Create a wave to contain Pressure values between a minimum pressure of 1 Erg/cm3, up to pmax.  The do while loops
	//increases the pressure rapidly at first and then slows down as pmax is approached.  Two different loops can be used depending on the Max Pressure.  This is probably the most perplexing part of the 
	//whole program.  I've had difficulting setting up a loop for all conditions so that small separations will be determined for the constant potential case.  You may find that the constant potential solution does
	//not make it to small separations, for very low ionic strength and/or very low surface potentials.
	if(pmax<3e4)
	//	print "firstloop"
		do
		n+=1
		if(p<=128)
			p=p*1.25
			if (p<pmax)
				make/o/n=(n) pressure_CP
				pressure_CP[n] = p
			else
				do
				make/o/n=(n) pressure_CP
				pressure_CP[n] = pressure_CP[n-2] *1.08
				n+=1
				while (pressure_CP[n]<pmax)
			endif
		elseif((p>128) && (p<=500))
			p=p*1.08
			if (p<pmax)
				make/o/n=(n) pressure_CP
				pressure_CP[n] = p 
			else
				do
				make/o/n=(n) pressure_CP
				pressure_CP[n] = pressure_CP[n-2] *1.05
				n+=1
				while (pressure_CP[n]<pmax)
			endif
		elseif((p>500) && (p<=pmax))
			p=p*1.05
			if (p<pmax)
				make/o/n=(n) pressure_CP
				pressure_CP[n] = p
			else
				do
				make/o/n=(n) pressure_CP
				pressure_CP[n] = pressure_CP[n-2] *1.03
				n+=1
				while (pressure_CP[n]<pmax)
			endif
		else
		endif
		while(p<=pmax)
		
	else
		//print "Second Loop"
		do
			n+=1
			if(p<=1.024e3)
				p=p*1.25
				if (p<pmax)
					make/o/n=(n) pressure_CP
					pressure_CP[n] = p
				else
					do
						make/o/n=(n) pressure_CP
						pressure_CP[n] = pressure_CP[n-2] *1.08
						n+=1
					while (pressure_CP[n]<pmax)
				endif
			elseif((p>1.024e3) && (p<=1e5))
				p=p*1.08
				if (p<pmax)
					make/o/n=(n) pressure_CP
					pressure_CP[n] = p
				else
					do
						make/o/n=(n) pressure_CP
						pressure_CP[n] = pressure_CP[n-2] *1.08
						n+=1
					while (pressure_CP[n]<pmax)
				endif
			elseif((p>1e5) && (p<=pmax))
				p=p*1.05
				if (p<pmax)
					make/o/n=(n) pressure_CP
					pressure_CP[n] = p
				else
					do
						make/o/n=(n) pressure_CP
						pressure_CP[n] = pressure_CP[n-2] *1.03
						n+=1
					while (pressure_CP[n]<pmax)
				endif
				
			else
			endif	
	while (p<=pmax)
	endif
	
	
	//Interpolate the pressure wave to increase the number of data points in wave
	interpolate2/i=0/n=500/T=1 pressure_CP			//creates as wave called pressure_CP_L
	
	
	
	//Make waves to contain the results
	make/o/n=(500) fEperA_CP,output_CP,separation_CP,EperA_CP,lnEperA_CP,vdW_CP,DLVO_CP,lnDLVO_CP,RetardFactor_CP
	wave Pressure_CP_L								//this in interpolated wave that is created from above
	Ym = 1.0 + 1/(TwoNkt)							//Starting midplane potential unitless, pressure is in Erg/cm3 
	Step =(sqrt(2*(cosh(Ys) - (Ym))))/1000				//step size for the rungakutta numerical solution
	fEperA_CP[j] = 1*Debye							//The first Energy per unit area term is simply equal to the minimum pressure times the debye length mJ/m2
	EperA_CP[j] = fEperA_CP[j]						//EperA will become the integrated pressure, at this point in the routine, there is only one data point
	
	
	//Calculate the distance between the midplane and the surface for the initial minimum pressure, using a RungaKutta numerical method
	Do
			A = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
			Q = Q + step/2
			B = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
			C = B
			Q = Q + step/2
			D = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
			Xscal = Xscal + (A + 2*B + 2*C + D)/6
			i=i+1
	While (i<1000)
	output_CP[j] = Xscal										//adds the scaled distance value to the first position in a wave called output
	Separation_CP[j] = (output_CP[j]*Debye*2e7)				//the separation in units of nanometers.  The two is because Xscal = Separation/debye*2
	RetardFactor_CP[j] = .019241 + .29168*exp(-.0086425*separation_CP[j]) + .70325*exp(-.048717*Separation_CP[j])  //retardation of hamaker constant.  This is a fit of tabulated data for infinite plates presented in R.J. Hunter's Paper: Aust. J. Chem.,1963,774-8
	vdW_CP[j] = (-v2*RetardFactor_CP[j]/(12*PI*(Separation_CP[j]^2)))*1e18*1000      //vdW POSITION 1.          vdW's force using a retarded hamaker constant.  Unit mJ/m2
	lnEperA_CP[j] = ln(EperA_CP[j])							//simply takes the ln of the integrated pressure
	DLVO_CP[j] = EperA_CP[j] + vdW_CP[j]					//adds the vdW force 
	lnDLVO_CP[j] = ln(DLVO_CP[j])							//simply takes the ln of the DLVO force
	
	//calculate a new scaled distance based on a change in the midplane potential Ym.  		
	Do	
		if(output_CP[j]<0.03)								//this breaks the do while loop if the separation falls below to small a value.  You can experiment with this, if you find your result does not achieve small separaitons
			break
		else	
			j=j+1	
			Ym = 1.0 + pressure_CP_L[j]/(TwoNkt)			//uses the next pressure value in the wave we created above, to calculate a new midplane potential and the next separation distance
			subrungakutta_CP(Ym,j)						//calls the function SubRungaKutta, listed below.
		endif
	While (j<=500)											//continues loop until all pressure values have been used
	
	redimension/N=(j)  fEperA_CP,output_CP,separation_CP,EperA_CP,lnEperA_CP,vdW_CP,DLVO_CP,lnDLVO_CP,RetardFactor_CP,pressure_CP_L
	
	//plot out some data
	if(v4==1)
		
		dowindow/r/k EnergyperArea	
		display/N=EnergyperArea/W=(15,30,400,230) DLVO_CP vs separation_CP
		ModifyGraph tick=2,standoff=0,btLen=3;DelayUpdate
		Legend/C/N=text0/J/A=MC/X=38/Y=45 "\\s(DLVO_CP) Constant Potential\r\\s(DLVO_CC) Constant Charge"
		Label left "E\\BA flat-flat\\M / mJ/m\\S2";DelayUpdate
		Label bottom "Separation / nm"
		dowindow/r/k Naturallogplot	
		display/N=naturallogplot/W=(15,278,400,488) lnDLVO_CP vs separation_CP
		ModifyGraph tick=2,standoff=0,btLen=3;DelayUpdate
		Legend/C/N=text0/J/A=MC/X=38/Y=45 "\\s(lnDLVO_CP) Constant Potential\r\\s(lnDLVO_CC) Constant Charge"
		Label left "ln( E\\BA\\M / mJ/m\\S2\\M )";DelayUpdate
		Label bottom "Separation / nm"
		
	else
		dowindow/r/k EnergyperArea	
		display/N=EnergyperArea/W=(15,30,400,230) EperA_CP vs separation_CP
		Legend/C/N=text0/J/A=MC/X=38/Y=45 "\\s(EperA_CP) Constant Potential\r\\s(EperA_CC) Constant Charge"
		ModifyGraph tick=2,standoff=0,btLen=3
		Label left "E\\BA flat-flat\\M / mJ/m\\S2";DelayUpdate
		Label bottom "Separation / nm"
		dowindow/r/k Naturallogplot	
		display/N=naturallogplot/W=(15,278,400,488) lnEperA_CP vs separation_CP
		ModifyGraph tick=2,standoff=0,btLen=3;DelayUpdate
		Legend/C/N=text0/J/A=MC/X=38/Y=45 "\\s(lnEperA_CP) Constant Potential\r\\s(lnEperA_CC) Constant Charge"
		Label left "ln( E\\BA\\M / mJ/m\\S2\\M )";DelayUpdate
		Label bottom "Separation / nm"
		
	endif
End

//Constant Potential Subroutine that is called from above
Function subRungaKutta_CP(Ym,j)
	variable Ym
	variable j
	variable i, Q, Xscal,A, B, C, D, Ys, Step, kappa, conv, Debye
	nVar v1 = root:surfacepotential
	nVar v2 = root:Hamaker
	nVar v3 = root:ionicstrength
	nVar v4 = root:Temp
	nVar v5 = root:DC
	nVar v6 = root:SphereRadius
	
	// lets the function know which waves will be used
	wave pressure_CP, pressure_CP_L, output_CP, separation_CP,fEperA_CP, EperA_CP,lnEperA_CP, vdW_CP,DLVO_CP,lnDLVO_CP,RetardFactor_CP
	
	// variable declarations
	i=0;Xscal=0;Q=0
	conv =v5*1.380658e-16*v4/(2*PI*(4.803e-10)^2) 			//same as above
	kappa = 1e8*sqrt(1000*conv/(4*6.02213e23))				//same as above
	Ys =v1*1.602e-19/(1.380658e-23*v4)					//same as above
	Step = (sqrt(2*(cosh(Ys) - Ym)))/1000					//the step size has changed because Ym has increased
	Debye = (kappa/(sqrt(v3)))*1e-8							//same as above

	//Calculate the distance between the midplane Ym, and the surface for the new pressure value, using a RungaKutta numerical method
	Do
				A = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				Q = Q + Step/2
				B = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				C = B
				Q = Q + Step/2
				D = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				Xscal = Xscal + (A + 2*B + 2*C + D)/6
				i=i+1
	while(i<1000)
	output_CP[j] = Xscal									//add the new scaled distance to the end of the wave output
	Separation_CP[j] = (output_CP[j]*Debye*2e7)			//convert the scaled distance to nanometer
	RetardFactor_CP[j] = .019241 + .29168*exp(-.0086425*separation_CP[j]) + .70325*exp(-.048717*separation_CP[j])
	vdW_CP[j] = (-v2*RetardFactor_CP[j]/(12*PI*(Separation_CP[j]^2)))*1e18*1000								  // vdW POSITION 2. 
	fEperA_CP[j] = -(((Separation_CP[j] - Separation_CP[j-1])/2e7))*(pressure_CP_L[j] + pressure_CP_L[j-1])		  //integration of pressure			
	EperA_CP[j] = fEperA_CP[j] + EperA_CP[j-1]			//adds the area under the current pressure distance curve.  Each iteration of the do-while loop changes this value
	lnEperA_CP[j] = ln(EperA_CP[j]) 						
	DLVO_CP[j] = EperA_CP[j] + vdW_CP[j]
	lnDLVO_CP[j] = ln(DLVO_CP[j])
	//returns back to the RungaKutta_CP function, to create a new Ym value and then returns to this funtion.  Loops until 500 Ym values have been created between the minimum and maximum pressure
end

//
//
//
//
//
//
//
//CONSTANT CHARGE
Function RungaKuttaCC()
	Variable Q, Xscal 								
	Variable A, B, C, D, step, Ys, ym, p, i, j, n, pm, pmax, kappa, conv, TwoNkT, Debye
	nVar v1 = root:surfacepotential
	nVar v2 = root:Hamaker
	nVar v3 = root:ionicstrength
	nVar v4 = root:ChargeDensity
	nVar v5 = root:vdW
	nVar v6 = root:Temp
	nVar v7 = root:DC
	nVar v8 = root:SphereRadius
	
	// variable declarations
	Q = 0;Xscal=0
	p = 1;i=0;n=0;j=0
	TwoNkt = 2*1.380658e-16*v6*(v3)*6.02213e23/1000		
	conv = v7*1.380658e-16*v6/(2*PI*(4.803e-10)^2)			
	kappa = 1e8*sqrt((1000*conv)/(4*6.02213e23))			
	Ys =abs(v1*1.602e-19/(1.380658e-23*v6))						
	pmax =TwoNkt*(cosh(ys) - 1)						
	pm = 100*pmax										//for constant charge conditions, the surface potential is not constant.  I've simply multiplied the max pressure by 100 to ensure a minimum separation can be calculated
	pmax=pmax+pm
	Debye = (kappa/(sqrt(v3)))*1e-8			

	
	//Create a wave to contain Pressure values between a minimum pressure of 1 Erg/cm3, up to pmax.  The do while loop
	//increases to pressure rapidly at first and then slows down as pmax is approached.  
	if(datafolderexists("root:constantCharge"))
	setdatafolder root:ConstantCharge
	else
	newdatafolder root:ConstantCharge
	setdatafolder root:ConstantCharge
	endif
	
	
	do
		n+=1
		if(p<=1.024e3)
			p=p*1.5
			make/o/n=(n) pressure_CC
			pressure_CC[n] = p
		elseif((p>1.024e3) && (p<=1e5))
			p=p*1.08
			make/o/n=(n) pressure_CC
			pressure_CC[n] = p
		elseif((p>1e5) && (p<pmax))
			p=p*1.05
			if (p<pmax)
			make/o/n=(n) pressure_CC
			pressure_CC[n] = p
			else
			endif
		else
		endif
	while (p<pmax)
	
	interpolate2/i=0/n=1000/T=1 pressure_CC
	
	make/o/n=1000 fEperA_CC,output_CC,separation_CC,EperA_CC,lnEperA_CC,vdW_CC,DLVO_CC,lnDLVO_CC,RetardFactor_CC,SurfacePotential_CC
	wave pressure_CC_L
	Ym = 1.0 + 1/(TwoNkt)							
	if(v4==0)
		Step =(exp(Ys/2) - 1/(exp(Ys/2)))/1000							//step size for the rungakutta numerical integration if the initial surface potential is used
	else
		Step = (2e12*Debye*(v4/1.602e-3)/conv)/1000					//step size for the rungakutta numerical integration if using the charge density
	endif
	fEperA_CC[j] = 1*Debye							
	EperA_CC[j] = fEperA_CC[j]								
	SurfacePotential_CC[j] = Ys
	
	//Calculate the distance between the midplane and the surface for the initial minimum pressure, using a RungaKutta numerical method
		Do
				A = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				Q = Q + step/2
				B = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				C = B
				Q = Q + step/2
				D = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				Xscal = Xscal + (A + 2*B + 2*C + D)/6
				i=i+1
		While (i<1000)
	output_CC[j] = Xscal	
	Separation_CC[j] = (output_CC[j]*Debye*2e7)	
	RetardFactor_CC[j] = .019241 + .29168*exp(-.0086425*separation_CC[j]) + .70325*exp(-.048717*separation_CC[j])
	vdW_CC[j] = (-v2*RetardFactor_CC[j]/(12*PI*(Separation_CC[j]^2)))*1e18*1000											 //vdW POSITION 3
	lnEperA_CC[j] = ln(EperA_CC[j])							
	DLVO_CC[j] = EperA_CC[j] + vdW_CC[j]
	lnDLVO_CC[j] = ln(DLVO_CC[j])
	
	//calculate a new scaled distance based on a change in the midplane potential Ym.  		
		Do		
			if(output_CC[j]<0.03)
				break
			else
					j=j+1	
					Ym = 1.0 + pressure_CC_L[j]/(TwoNkt)		
					subrungakutta_CC(Ym,j)	
			endif
		While (j<=1000)
	
	redimension/N=(j)  fEperA_CC,output_CC,separation_CC,EperA_CC,lnEperA_CC,vdW_CC,DLVO_CC,lnDLVO_CC,RetardFactor_CC,pressure_CC_L,SurfacePotential_CC

	//plot out some data
	if(v5==0)	
		wavestats/Q/W EperA_CC
		variable l
		l = v_max	
		appendtograph/W=EnergyperArea EperA_CC vs separation_CC
		ModifyGraph/W=EnergyperArea rgb(EperA_CC)=(0,0,0)
		setaxis/W=EnergyperArea left -0.05,(l+.01)
		appendtograph/W=naturallogplot lnEperA_CC vs separation_CC
		ModifyGraph/W=Naturallogplot rgb(lnEperA_CC)=(0,0,0)
	else
		wavestats/Q/W DLVO_CC
		variable o
		o = v_max
		appendtograph/W=EnergyperArea DLVO_CC vs separation_CC
		ModifyGraph/W=EnergyperArea rgb(DLVO_CC)=(0,0,0)
		setaxis/W=EnergyperArea left -0.05,(o+.01)
		appendtograph/W=naturallogplot lnDLVO_CC vs separation_CC
		ModifyGraph/W=Naturallogplot rgb(lnDLVO_CC)=(0,0,0)	
	endif
End

//Constant charge subroutine
Function subRungaKutta_CC(Ym,j)
	variable Ym
	variable j
	variable akappa, i, Q, Xscal, A, B, C, D, Ys, Step,kappa, conv, Debye
	nVar v1 = root:surfacepotential
	nVar v2 = root:Hamaker
	nVar v3 = root:ionicstrength
	nVar v4 = root:ChargeDensity
	nVar v5 = root:Temp
	nVar v6 = root:DC
	nVar v7 = root:SphereRadius
	wave pressure_CC, Pressure_CC_L,output_CC, separation_CC,fEperA_CC, EperA_CC,lnEperA_CC, vdW_CC,DLVO_CC,lnDLVO_CC,RetardFactor_CC,SurfacePotential_CC
	
	//variable declaration
	i=0;Xscal=0;Q=0
	conv = v6*1.380658e-16*v5/(2*PI*(4.803e-10)^2) 			
	kappa = 1e8*sqrt(1000*conv/(4*6.02213e23))		
	Ys =abs(v1*1.602e-19/(1.380658e-23*v5))					
	Debye = (kappa/(sqrt(v3)))*1e-8							
	
	if(v4==0)
		Step =(exp(Ys/2) - 1/(exp(ys/2)))/1000				//step size for the rungakutta numerical integration if using the potential
	else
		Step = (2e12*Debye*(v4/1.602e-3)/conv)/1000		//step size for the rungakutta numerical integration if using the charge density
	endif				
	
	
	//Calculate the distance between the midplane Ym, and the surface for the new pressure value, using a RungaKutta numerical method
	Do
				A = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				Q = Q + Step/2
				B = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				C = B
				Q = Q + Step/2
				D = Step/sqrt((((Q^2)/2 + Ym)^2) - 1)
				Xscal = Xscal + (A + 2*B + 2*C + D)/6
				i=i+1
	while(i<1000)
	output_CC[j] = Xscal										
	Separation_CC[j] = (output_CC[j]*Debye*2e7)
	RetardFactor_CC[j] = .019241 + .29168*exp(-.0086425*separation_CC[j]) + .70325*exp(-.048717*separation_CC[j])
	vdW_CC[j] = (-v2*RetardFactor_CC[j]/(12*PI*(Separation_CC[j]^2)))*1e18*1000												 // vdW POSiTION 4
	fEperA_CC[j] = -(((Separation_CC[j] - Separation_CC[j-1])/2e7))*(pressure_CC_L[j] + pressure_CC_L[j-1])		
	EperA_CC[j] = fEperA_CC[j] + EperA_CC[j-1]				
	lnEperA_CC[j] = ln(EperA_CC[j]) 							
	DLVO_CC[j] = EperA_CC[j] + vdW_CC[j]
	lnDLVO_CC[j] = ln(DLVO_CC[j])
end

//This is the button "Graph Electrostatic Fit"
Function ButtonProc_23(ctrlName) : ButtonControl
	String ctrlName
	RungaKuttaCP()
	killwaves/Z output_CP,fEperA_CP,RetardFactor_CP
	RungaKuttaCC()
	killwaves/Z output_CC,fEperA_CC,RetardFactor_CC,M_wavestats
	Setdatafolder root:
	
end

//This button does the charge density conversion
Function ButtonProc_9(ctrlName) : ButtonControl
	String ctrlName
	setdatafolder root:
	nVar v1 = AreaPCharge
	nVar v2 = ChargeDensity
	v2 = 1/(v1/(1.602e-19*1e18))
End

Window DLVO() : Panel
	PauseUpdate; Silent 1		// building window...
	NewPanel /W=(871,417,1256,869)
	ModifyPanel cbRGB=(65280,65280,16384), frameInset=5
	SetDrawLayer UserBack
	SetDrawEnv fsize= 15,fstyle= 5,textrgb= (0,0,52224)
	DrawText 16,126,"Constant Surface Potential"
	SetDrawEnv fsize= 15,fstyle= 5,textrgb= (0,0,52224)
	DrawText 17,179,"Constant Surface Charge"
	SetDrawEnv textrgb= (0,15872,65280)
	DrawText 113,216,"If you leave the Charge Density at Zero, the"
	SetDrawEnv textrgb= (0,15872,65280)
	DrawText 112,228,"program will use the Surface Potential at"
	SetDrawEnv textrgb= (0,15872,65280)
	DrawText 112,241,"infinite separation as starting surface potential"
	SetDrawEnv textrgb= (0,15872,65280)
	DrawText 21,304,"Just a converter.  Clicking button will change"
	SetDrawEnv textrgb= (0,15872,65280)
	DrawText 264,304,"value above"
	SetDrawEnv fsize= 15,fstyle= 5,textrgb= (0,0,52224)
	DrawText 16,30,"Solution Conditions"
	DrawLine 15,-2,15,357
	SetDrawEnv fillfgc= (52224,0,0)
	DrawRect 16,-2,0,451
	SetDrawEnv textrgb= (0,0,65280)
	DrawText 24,368,"Users may wish to supply various vdW's equations to account "
	SetDrawEnv textrgb= (0,0,65280)
	DrawText 24,382,"for the retardation of the Hamaker constant as a function of"
	SetDrawEnv textrgb= (0,0,65280)
	DrawText 24,396,"distance.  I have marked the four positions in the proceedure file "
	SetDrawEnv textrgb= (0,0,65280)
	DrawText 24,410,"where you will need to insert your own vdW's relationship.  "
	SetDrawEnv textrgb= (0,0,65280)
	DrawText 23,423,"Currently the proceedure uses a retarded vdW's force."
	SetDrawEnv textrgb= (0,0,65280)
	DrawText 23,437,"Retardation based on the following citation:"
	SetDrawEnv textrgb= (0,0,65280)
	DrawText 23,450,"Hunter R.J., Aust. J. Chem., 1963,16,774-8"
	SetVariable setvar0,pos={93,129},size={288,16},title="Surface Potential at infinite Separation / V"
	SetVariable setvar0,value= SurfacePotential
	SetVariable setvar4,pos={219,31},size={160,16},title="Ionic Strength / M"
	SetVariable setvar4,value= ionicstrength
	Button button2,pos={143,334},size={155,20},proc=ButtonProc_23,title="\\K(0,0,52224)Graph Electrostatic Force"
	Button button2,fStyle=1
	SetVariable setvar2,pos={141,183},size={240,16},title="Charge Density / Coulomb/m^2"
	SetVariable setvar2,value= ChargeDensity
	Button button0,pos={18,240},size={185,50},proc=ButtonProc_9,title="Convert Area/Charge (nm\\S2\\M)\rto Charge Density (C/m\\S2\\M)"
	SetVariable setvar1,pos={204,251},size={177,16},title="Area/Charge / nm^2"
	SetVariable setvar1,value= AreaPCharge
	SetVariable setvar3,pos={246,71},size={134,16},title="Hamaker / J"
	SetVariable setvar3,value= Hamaker
	CheckBox check0,pos={303,337},size={70,14},title="Add vdW's",variable= vdW
	SetVariable setvar5,pos={224,52},size={156,16},title="Temperature / K"
	SetVariable setvar5,value= Temp
	SetVariable setvar6,pos={160,91},size={221,16},title="Dielectric Constant of Water"
	SetVariable setvar6,value= DC
EndMacro


